==> m17n-docs_1.8.3.orig.tar.gz: m17n-docs-1.8.3/ja/html/search/all_b.js <==
var searchData=
[
  ['langsys_261',['langsys',['../structMFLTOtfSpec.html#adcbcda3c2b2b2a183e36d9e856c7ee68',1,'MFLTOtfSpec']]],
  ['langsys_5ftag_262',['langsys_tag',['../structMFontCapability.html#a1a6c661d7a5fde0842e7d9354082a6c4',1,'MFontCapability']]],
  ['language_263',['language',['../structMInputMethod.html#ad418711bca43a10b3afb2939cd752eb9',1,'MInputMethod::language()'],['../structMFontCapability.html#a08d8d836448c87d8d7319042a0710cff',1,'MFontCapability::language()'],['../struct__MInputMethodInfo.html#ae7d246895289948143a85b55c52b27d4',1,'_MInputMethodInfo::language()']]],
  ['language_2ec_264',['language.c',['../language_8c.html',1,'']]],
  ['language_2eh_265',['language.h',['../language_8h.html',1,'']]],
  ['last_5fblock_266',['last_block',['../structMConverter.html#a25e07110149579b8867e4795b280e868',1,'MConverter']]],
  ['layouter_267',['layouter',['../structMRealizedFace.html#a514f85e7446cbf510eb17c7dfdb67d78',1,'MRealizedFace::layouter()'],['../structMRealizedFont.html#a9a29971bf1e3bc5c7473f8cbd95a96c3',1,'MRealizedFont::layouter()']]],
  ['lbearing_268',['lbearing',['../structMFLTGlyph.html#a262d31edb49b724d4150812689ab05ef',1,'MFLTGlyph::lbearing()'],['../structMDrawGlyph.html#a0ac28c3492847ea5b776c4dbdc87c1a3',1,'MDrawGlyph::lbearing()'],['../structMGlyphString.html#adbf1bf22861688b29e987ab897eb6de2',1,'MGlyphString::lbearing()']]],
  ['left_5ffrom_269',['left_from',['../structMDrawGlyphInfo.html#a36e10a86b98aa88745772554de3f79e3',1,'MDrawGlyphInfo']]],
  ['left_5fpadding_270',['left_padding',['../structMGlyph.html#a4459ddc73e714cfafbbb843ec4d2cd1b',1,'MGlyph']]],
  ['left_5fto_271',['left_to',['../structMDrawGlyphInfo.html#a81c27750a20614fb98e1e084e675ff0d',1,'MDrawGlyphInfo']]],
  ['len_272',['len',['../structMDatabaseInfo.html#a958706a57b7742ef1992ae261e76f1ed',1,'MDatabaseInfo']]],
  ['length_273',['length',['../structMSymbol.html#a25155301b18d08b066b9cc1c1b3efaa1',1,'MSymbol']]],
  ['lenient_274',['lenient',['../structMConverter.html#a1e6ac361d7ec9fc7b8e6471641b8df05',1,'MConverter']]],
  ['libotf_5fpositioning_5ftype_275',['libotf_positioning_type',['../structMGlyph.html#aa4c66e07b5c2f3fa2ea44141caa2015d',1,'MGlyph']]],
  ['line_5fascent_276',['line_ascent',['../structMGlyphString.html#a3b46afee85b8b3fe488613b713c78c83',1,'MGlyphString']]],
  ['line_5fbreak_277',['line_break',['../structMDrawControl.html#a9bdfae9e6a769c7b10f5d4d99226527d',1,'MDrawControl']]],
  ['line_5fdescent_278',['line_descent',['../structMGlyphString.html#aded0b60724adacdc9dff47ca27d8e0b3',1,'MGlyphString']]],
  ['line_5ffrom_279',['line_from',['../structMDrawGlyphInfo.html#a62fdb2ac09992ee300c3d30c67088ca3',1,'MDrawGlyphInfo']]],
  ['line_5fto_280',['line_to',['../structMDrawGlyphInfo.html#ab31beb42b28acbb75f1f8debe9819508',1,'MDrawGlyphInfo']]],
  ['list_281',['list',['../structMFontDriver.html#a477c6f00f8731976ab242bf60668a77e',1,'MFontDriver']]],
  ['list_5ffamily_5fnames_282',['list_family_names',['../structMFontDriver.html#a095a884dbf9a2dbcd6f8eea1b7927d68',1,'MFontDriver']]],
  ['locale_283',['locale',['../structMInputXIMArgIM.html#ade42ccfe5b1e4587a2dd0e9cf019a764',1,'MInputXIMArgIM']]],
  ['locale_2ec_284',['locale.c',['../locale_8c.html',1,'']]],
  ['lock_5ffile_285',['lock_file',['../structMDatabaseInfo.html#ab7ee5039f92c11d58d4da8bfe1690a19',1,'MDatabaseInfo']]],
  ['logical_5fwidth_286',['logical_width',['../structMDrawGlyphInfo.html#a5a4d7a62d82388285dc35d677a25d7c9',1,'MDrawGlyphInfo']]],
  ['lookup_287',['lookup',['../structMInputDriver.html#acf5fa6a15099d9d4f6888046ad634bb4',1,'MInputDriver']]]
];

==> m17n-docs_1.8.4.orig.tar.gz: m17n-docs-1.8.4/ja/html/search/all_b.js <==
var searchData=
[
  ['langsys_261',['langsys',['../structMFLTOtfSpec.html#adcbcda3c2b2b2a183e36d9e856c7ee68',1,'MFLTOtfSpec']]],
  ['langsys_5ftag_262',['langsys_tag',['../structMFontCapability.html#a1a6c661d7a5fde0842e7d9354082a6c4',1,'MFontCapability']]],
  ['language_263',['language',['../structMInputMethod.html#ad418711bca43a10b3afb2939cd752eb9',1,'MInputMethod::language()'],['../structMFontCapability.html#a08d8d836448c87d8d7319042a0710cff',1,'MFontCapability::language()'],['../struct__MInputMethodInfo.html#ae7d246895289948143a85b55c52b27d4',1,'_MInputMethodInfo::language()']]],
  ['language_2ec_264',['language.c',['../language_8c.html',1,'']]],
  ['language_2eh_265',['language.h',['../language_8h.html',1,'']]],
  ['last_5fblock_266',['last_block',['../structMConverter.html#a25e07110149579b8867e4795b280e868',1,'MConverter']]],
  ['layouter_267',['layouter',['../structMRealizedFace.html#a514f85e7446cbf510eb17c7dfdb67d78',1,'MRealizedFace::layouter()'],['../structMRealizedFont.html#a9a29971bf1e3bc5c7473f8cbd95a96c3',1,'MRealizedFont::layouter()']]],
  ['lbearing_268',['lbearing',['../structMFLTGlyph.html#a262d31edb49b724d4150812689ab05ef',1,'MFLTGlyph::lbearing()'],['../structMDrawGlyph.html#a0ac28c3492847ea5b776c4dbdc87c1a3',1,'MDrawGlyph::lbearing()'],['../structMGlyphString.html#adbf1bf22861688b29e987ab897eb6de2',1,'MGlyphString::lbearing()']]],
  ['left_5ffrom_269',['left_from',['../structMDrawGlyphInfo.html#a36e10a86b98aa88745772554de3f79e3',1,'MDrawGlyphInfo']]],
  ['left_5fpadding_270',['left_padding',['../structMGlyph.html#a4459ddc73e714cfafbbb843ec4d2cd1b',1,'MGlyph']]],
  ['left_5fto_271',['left_to',['../structMDrawGlyphInfo.html#a81c27750a20614fb98e1e084e675ff0d',1,'MDrawGlyphInfo']]],
  ['len_272',['len',['../structMDatabaseInfo.html#a958706a57b7742ef1992ae261e76f1ed',1,'MDatabaseInfo']]],
  ['length_273',['length',['../structMSymbolStruct.html#a25155301b18d08b066b9cc1c1b3efaa1',1,'MSymbolStruct']]],
  ['lenient_274',['lenient',['../structMConverter.html#a1e6ac361d7ec9fc7b8e6471641b8df05',1,'MConverter']]],
  ['libotf_5fpositioning_5ftype_275',['libotf_positioning_type',['../structMGlyph.html#aa4c66e07b5c2f3fa2ea44141caa2015d',1,'MGlyph']]],
  ['line_5fascent_276',['line_ascent',['../structMGlyphString.html#a3b46afee85b8b3fe488613b713c78c83',1,'MGlyphString']]],
  ['line_5fbreak_277',['line_break',['../structMDrawControl.html#a9bdfae9e6a769c7b10f5d4d99226527d',1,'MDrawControl']]],
  ['line_5fdescent_278',['line_descent',['../structMGlyphString.html#aded0b60724adacdc9dff47ca27d8e0b3',1,'MGlyphString']]],
  ['line_5ffrom_279',['line_from',['../structMDrawGlyphInfo.html#a62fdb2ac09992ee300c3d30c67088ca3',1,'MDrawGlyphInfo']]],
  ['line_5fto_280',['line_to',['../structMDrawGlyphInfo.html#ab31beb42b28acbb75f1f8debe9819508',1,'MDrawGlyphInfo']]],
  ['list_281',['list',['../structMFontDriver.html#a477c6f00f8731976ab242bf60668a77e',1,'MFontDriver']]],
  ['list_5ffamily_5fnames_282',['list_family_names',['../structMFontDriver.html#a095a884dbf9a2dbcd6f8eea1b7927d68',1,'MFontDriver']]],
  ['locale_283',['locale',['../structMInputXIMArgIM.html#ade42ccfe5b1e4587a2dd0e9cf019a764',1,'MInputXIMArgIM']]],
  ['locale_2ec_284',['locale.c',['../locale_8c.html',1,'']]],
  ['lock_5ffile_285',['lock_file',['../structMDatabaseInfo.html#ab7ee5039f92c11d58d4da8bfe1690a19',1,'MDatabaseInfo']]],
  ['logical_5fwidth_286',['logical_width',['../structMDrawGlyphInfo.html#a5a4d7a62d82388285dc35d677a25d7c9',1,'MDrawGlyphInfo']]],
  ['lookup_287',['lookup',['../structMInputDriver.html#acf5fa6a15099d9d4f6888046ad634bb4',1,'MInputDriver']]]
];
